#!/usr/bin/python
#
# Copyright 2018-2020 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

    Polyaxon SDKs and REST API specification.  # noqa: E501

    OpenAPI spec version: 1.0.5
    Contact: contact@polyaxon.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import polyaxon_sdk
from polyaxon_sdk.models.v1_project_entity_resource_request import (
    V1ProjectEntityResourceRequest,
)  # noqa: E501
from polyaxon_sdk.rest import ApiException


class TestV1ProjectEntityResourceRequest(unittest.TestCase):
    """V1ProjectEntityResourceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1ProjectEntityResourceRequest(self):
        """Test V1ProjectEntityResourceRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = polyaxon_sdk.models.v1_project_entity_resource_request.V1ProjectEntityResourceRequest()  # noqa: E501
        pass


if __name__ == "__main__":
    unittest.main()
